# 555 empathize

**Description:** Considers human and stakeholder perspectives. The "empathize" stage introduces an empathic view to evaluate emotional, social, or ethical implications.

**Usage:** `555 empathize`

This stage inserts considerations about how different people are affected or what their viewpoints might be.
